package service

import (
	"IC/utils"
	_ "IC/utils"
	_ "encoding/json"
	"fmt"
	oracle "github.com/godoes/gorm-oracle"
	_ "github.com/godror/godror"
	"gorm.io/gorm"
	_ "strconv"
	"time"
)

type wzLisReport struct {
	Repno          string `gorm:"column:REPNO" json:"REPNO"`
	Repname        string `gorm:"column:REPNAME" json:"REPNAME"`
	NAME           string `gorm:"column:NAME" json:"NAME"`
	Appdeptname    string `gorm:"column:APPDEPTNAME" json:"APPDEPTNAME"`
	Fisrtaudittime string `gorm:"column:FISRTAUDITTIME" json:"FISRTAUDITTIME"`
}

func (wzLisReport) TableName() string {
	return "V_LIS_REPORT"
}

type wzLisReportResult struct {
	Repno     string `gorm:"column:REPNO" json:"REPNO"`
	Itemid    string `gorm:"column:ITEMID" json:"ITEMID"`
	Itemcname string `gorm:"column:ITEMCNAME" json:"ITEMCNAME"`
	Itemename string `gorm:"column:ITEMENAME" json:"ITEMENAME"`
	Result    string `gorm:"column:RESULT" json:"RESULT"`
	Unit      string `gorm:"column:UNIT" json:"UNIT"`
	Prompt    string `gorm:"column:PROMPT" json:"PROMPT"`
	Refmax    string `gorm:"column:REFMAX" json:"REFMAX"`
	Refmin    string `gorm:"column:REFMIN" json:"REFMIN"`
	Time      string `gorm:"column:TIME" json:"TIME"`
}

func (wzLisReportResult) TableName() string {
	return "V_LIS_REPORT_RESULT"
}

func GetSzwzyLisReport(rdb *gorm.DB, synctime string) (record []*wzLisReport, err error) {
	err = rdb.Model(&wzLisReport{}).Where("FISRTAUDITTIME >= ? and APPDEPTNAME = '肾病科'", synctime).Find(&record).Error
	return
}

func GetSzwzyLisReportResule(rdb *gorm.DB, repno string) (record []*wzLisReportResult, err error) {
	err = rdb.Model(&wzLisReportResult{}).Where("REPNO = ? ", repno).Find(&record).Error
	return
}

// 深圳五洲中医院Lis同步
func SyncLisSzwz() (err error) {

	org_id := int64(10580)
	// oracle://user:password@127.0.0.1:1521/service
	url := oracle.BuildUrl("172.9.200.3", 1521, "JKY", "BSLIS52", "zhsoft", nil)
	orgDb, err := gorm.Open(oracle.Open(url), &gorm.Config{})
	if err != nil {
		utils.ErrorLog("创建数据库连接失败:%v", err)
		return
	}

	// 第一步：获取上一次同步的时间点
	syncLastInfo, _ := GetSyncTimeByOrgIDForYs(org_id)
	var sync_time int64
	if syncLastInfo.ID > 0 {
		sync_time = syncLastInfo.SyncTime
	} else {
		sync_time = 1672502400 // 2023-01-01
	}

	SyncTime := time.Unix(sync_time, 0)
	syncTimeStr := SyncTime.Format("2006-01-02 15:04:05")

	fmt.Println(SyncTime)

	// 第二步：获取时间内所有检验结果
	szwzLisReport, _ := GetSzwzyLisReport(orgDb, syncTimeStr)
	if len(szwzLisReport) > 0 {
		for _, Report := range szwzLisReport {
			utils.InfoLog("Report:%v", Report)
			utils.InfoLog("患者姓名:%v", Report.NAME)
			if len(Report.Repname) <= 0 {
				Report.Repname = "未知"
			}
			patient, _ := GetUserInfoByName(org_id, Report.NAME)
			if patient.ID > 0 {
				// 第三步，根据REPNO查询对应的检查小项
				szwzLisReportResult, _ := GetSzwzyLisReportResule(orgDb, Report.Repno)
				if len(szwzLisReportResult) > 0 {
					for _, Result := range szwzLisReportResult {
						utils.InfoLog("Result:%v", Result)
					}
				}
			}
		}
	}
	return err
}
